@@ -1,11 +1,11 @@
-from qiskit import QuantumRegister, ClassicalRegister
+from qiskit import QuantumRegister
 from qiskit.circuit import QuantumCircuit
 
 
 def new_qram(address_count: int, data_count: int, values):
-    address = QuantumRegister(address_count)
-    data = QuantumRegister(data_count)
-    qc = QuantumCircuit(address, data)
+    address = QuantumRegister(address_count, name="addr")
+    data = QuantumRegister(data_count, name="data")
+    qc = QuantumCircuit(address, data, name="qram")
 
     key_i = 0
     for key in values:
@@ -28,7 +28,7 @@ def new_qram(address_count: int, data_count: int, values):
 
         for i in range(data_count):
             if v[i]:
-                qc.mct(address, data[i])
+                qc.mcx(address, data[i])
 
         for i in range(address_count):
             if not k[i]:
